/* $Id: libxfce4util.h 21068 2006-04-18 21:35:22Z benny $ */
/*-
 * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
 * All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __LIBXFCE4UTIL_LIBXFCE4UTIL_H__
#define __LIBXFCE4UTIL_LIBXFCE4UTIL_H__

#define LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H

#include <libxfce4util/libxfce4util-config.h>
#include <libxfce4util/libxfce4util-enum-types.h>

#include <libxfce4util/debug.h>
#include <libxfce4util/xfce-desktopentry.h>
#include <libxfce4util/xfce-fileutils.h>
#include <libxfce4util/xfce-generics.h>
#include <libxfce4util/xfce-i18n.h>
#include <libxfce4util/xfce-kiosk.h>
#include <libxfce4util/xfce-license.h>
#include <libxfce4util/xfce-miscutils.h>
#include <libxfce4util/xfce-rc.h>
#include <libxfce4util/xfce-resource.h>
#include <libxfce4util/xfce-utf8.h>

#define LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H

#endif  /* !__LIBXFCE4UTIL_LIBXFCE4UTIL_H__ */
